@@ -13,6 +13,7 @@ typedef Eo Efl_Loop_Message_Future;
 
 
 #endif
+#ifdef EFL_BETA_API_SUPPORT
 /** Used internally for futures on the loop
  *
  * @ingroup Efl_Loop_Message_Future
@@ -41,5 +42,6 @@ EOAPI void efl_loop_message_future_data_set(Eo *obj, void *data);
  * @ingroup Efl_Loop_Message_Future
  */
 EOAPI void *efl_loop_message_future_data_get(const Eo *obj);
+#endif /* EFL_BETA_API_SUPPORT */
 
 #endif
