@@ -13,16 +13,16 @@ typedef Eo Ecore_Audio_Out_Pulse;
 
 
 #endif
+#ifdef EFL_BETA_API_SUPPORT
 /** Ecore audio ouput for PulseAudio.
  *
  * @ingroup Ecore_Audio_Out_Pulse
  */
 #define ECORE_AUDIO_OUT_PULSE_CLASS ecore_audio_out_pulse_class_get()
 
-EWAPI const Eo_Class *ecore_audio_out_pulse_class_get(void);
+EWAPI const Efl_Class *ecore_audio_out_pulse_class_get(void);
 
-EOAPI extern const Eo_Event_Description _ECORE_AUDIO_OUT_PULSE_EVENT_CONTEXT_READY;
-EOAPI extern const Eo_Event_Description _ECORE_AUDIO_OUT_PULSE_EVENT_CONTEXT_FAIL;
+EWAPI extern const Efl_Event_Description _ECORE_AUDIO_OUT_PULSE_EVENT_CONTEXT_READY;
 
 /** Called when the output is ready for playback.
  *
@@ -30,10 +30,13 @@ EOAPI extern const Eo_Event_Description _ECORE_AUDIO_OUT_PULSE_EVENT_CONTEXT_FAI
  */
 #define ECORE_AUDIO_OUT_PULSE_EVENT_CONTEXT_READY (&(_ECORE_AUDIO_OUT_PULSE_EVENT_CONTEXT_READY))
 
+EWAPI extern const Efl_Event_Description _ECORE_AUDIO_OUT_PULSE_EVENT_CONTEXT_FAIL;
+
 /** Called when context fails.
  *
  * @ingroup Ecore_Audio_Out_Pulse
  */
 #define ECORE_AUDIO_OUT_PULSE_EVENT_CONTEXT_FAIL (&(_ECORE_AUDIO_OUT_PULSE_EVENT_CONTEXT_FAIL))
+#endif /* EFL_BETA_API_SUPPORT */
 
 #endif
