@@ -13,6 +13,7 @@ typedef Eo Efl_Net_Socket_Simple;
 
 
 #endif
+#ifdef EFL_BETA_API_SUPPORT
 /**
  * @brief A wrapper socket offering an easy to use, buffered I/O.
  *
@@ -46,12 +47,11 @@ typedef Eo Efl_Net_Socket_Simple;
  * @ref efl_io_buffered_stream_inner_io_set and can be retrieved with
  * @ref efl_io_buffered_stream_inner_io_get, which should be used with care.
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Socket_Simple
  */
 #define EFL_NET_SOCKET_SIMPLE_CLASS efl_net_socket_simple_class_get()
 
 EWAPI const Efl_Class *efl_net_socket_simple_class_get(void);
+#endif /* EFL_BETA_API_SUPPORT */
 
 #endif
