@@ -1,4 +1,44 @@
-#include "elm_interface_scrollable.eo.legacy.h"
+#ifndef _ELM_SCROLLER_LEGACY_H
+#define _ELM_SCROLLER_LEGACY_H
+#ifndef _ELM_INTERFACE_SCROLLABLE_EO_TYPES
+#define _ELM_INTERFACE_SCROLLABLE_EO_TYPES
+
+/**
+ * @brief Type that controls when scrollbars should appear.
+ *
+ * See also @ref elm_interface_scrollable_policy_set.
+ *
+ * @ingroup Elm_Scroller
+ */
+typedef enum
+{
+  ELM_SCROLLER_POLICY_AUTO = 0, /**< Show scrollbars as needed */
+  ELM_SCROLLER_POLICY_ON, /**< Always show scrollbars */
+  ELM_SCROLLER_POLICY_OFF, /**< Never show scrollbars */
+  ELM_SCROLLER_POLICY_LAST /**< Sentinel value to indicate last enum field
+                            * during iteration */
+} Elm_Scroller_Policy;
+
+/**
+ * @brief Type that controls how the content is scrolled.
+ *
+ * See also @ref elm_interface_scrollable_single_direction_set.
+ *
+ * @ingroup Elm_Scroller
+ */
+typedef enum
+{
+  ELM_SCROLLER_SINGLE_DIRECTION_NONE = 0, /**< Scroll every direction */
+  ELM_SCROLLER_SINGLE_DIRECTION_SOFT, /**< Scroll single direction if the
+                                       * direction is certain */
+  ELM_SCROLLER_SINGLE_DIRECTION_HARD, /**< Scroll only single direction */
+  ELM_SCROLLER_SINGLE_DIRECTION_LAST /**< Sentinel value to indicate last enum
+                                      * field during iteration */
+} Elm_Scroller_Single_Direction;
+
+
+#endif
+
 #include "elm_scroller_eo.legacy.h"
 
 /**
@@ -468,7 +508,7 @@ EAPI void                         elm_scroller_movement_block_set(Evas_Object *o
 /**
  * @brief Get a scroller's scroll blocking state
  *
- * @param parent The scroller object
+ * @param obj The scroller object
  * @return The blocking state
  *
  * @since 1.8
@@ -599,3 +639,4 @@ EAPI void elm_scroller_propagate_events_set(Evas_Object *obj, Eina_Bool propagat
  * @ingroup Elm_Scroller
  */
 EAPI Eina_Bool elm_scroller_propagate_events_get(const Evas_Object *obj);
+#endif
