@@ -11,24 +11,17 @@ typedef Eo Efl_Canvas_Object;
 #ifndef _EFL_CANVAS_OBJECT_EO_TYPES
 #define _EFL_CANVAS_OBJECT_EO_TYPES
 
-#ifdef EFL_BETA_API_SUPPORT
-/** Information of animation events
- *
- * @ingroup Efl_Canvas
- */
-typedef struct _Efl_Canvas_Object_Animation_Event Efl_Canvas_Object_Animation_Event;
-#endif /* EFL_BETA_API_SUPPORT */
-
 /** EFL event animator tick data structure
  *
  * @since 1.22
  *
- * @ingroup Efl
+ * @ingroup Efl_Event_Animator_Tick
  */
 typedef struct _Efl_Event_Animator_Tick
 {
   Eina_Rect update_area; /**< Area of the canvas that will be pushed to screen.
-                          */
+                          *
+                          * @since 1.22 */
 } Efl_Event_Animator_Tick;
 
 
@@ -657,7 +650,7 @@ EOAPI Eina_Bool efl_canvas_object_anti_alias_get(const Eo *obj);
  *
  * @ingroup Efl_Canvas_Object
  */
-EOAPI Eina_Iterator *efl_canvas_object_clipped_objects_get(const Eo *obj) EINA_WARN_UNUSED_RESULT;
+EOAPI Eina_Iterator *efl_canvas_object_clipped_objects_get(const Eo *obj) EFL_TRANSFER_OWNERSHIP EINA_WARN_UNUSED_RESULT;
 
 #ifdef EFL_CANVAS_OBJECT_PROTECTED
 /**
@@ -849,21 +842,6 @@ EOAPI Eina_Bool efl_canvas_object_no_render_get(const Eo *obj);
  */
 EOAPI Eina_Bool efl_canvas_object_coords_inside_get(const Eo *obj, Eina_Position2D pos);
 
-#ifdef EFL_BETA_API_SUPPORT
-/**
- * @brief Returns current canvas's gesture manager
- *
- * @param[in] obj The object.
- *
- * @return The gesture manager
- *
- * @since 1.22
- *
- * @ingroup Efl_Canvas_Object
- */
-EOAPI const Efl_Canvas_Gesture_Manager *efl_canvas_object_gesture_manager_get(Eo *obj);
-#endif /* EFL_BETA_API_SUPPORT */
-
 EWAPI extern const Efl_Event_Description _EFL_CANVAS_OBJECT_EVENT_ANIMATOR_TICK;
 
 /** Animator tick synchronized with screen vsync if possible.
