@@ -13,6 +13,7 @@ typedef Eo Efl_Canvas_Polygon;
 
 
 #endif
+#ifdef EFL_BETA_API_SUPPORT
 /** Low-level polygon object
  *
  * @ingroup Efl_Canvas_Polygon
@@ -36,5 +37,6 @@ EOAPI void efl_canvas_polygon_point_add(Eo *obj, Eina_Position2D pos);
  * @ingroup Efl_Canvas_Polygon
  */
 EOAPI void efl_canvas_polygon_points_clear(Eo *obj);
+#endif /* EFL_BETA_API_SUPPORT */
 
 #endif
